@@ -90,6 +90,10 @@ END
 
    DOWNLOAD         => 'Download',
 
+   DOWNLOAD_ALL     => 'Download entire dataset',
+
+   TRACK_ID         => 'Track ID=<b>%s</b>',
+
    DISPLAY_SETTINGS => 'Display Settings',
 
    TRACKS   => 'Tracks',
@@ -147,6 +151,8 @@ END
 
    SELECT_SUBTRACKS   => '%d of %d subtracks selected',
 
+   NO_TRACK_CITATION => 'There is no additional information about this track.',
+
    EDIT       => 'Edit File...',
 
    DELETE     => 'Delete File',
@@ -217,7 +223,7 @@ END
 
    REMOTE_TITLE => 'Add remote annotations',
 
-   IPAD_BALLOON => '\nTap feature again to see more details',
+   IPAD_BALLOON => 'Tap features twice to see more details',
 
    REMOTE_URL   => 'Enter remote track URL',
 
@@ -388,6 +394,7 @@ END
 
  ADD_DESCRIPTION    => 'Click to add a description',
  ADD_TITLE          => 'Click to edit the title',
+ EDIT_LABEL         => 'Click to view track. Shift or control-click to edit.',
  NO_DESCRIPTION     => 'No description',
 
  CONFIGURATION     => 'Configuration',
@@ -462,7 +469,7 @@ END
 
  DOWNLOAD_THIS_TRACK   => '<b>Download this track test</b>',
 
- ABOUT_THIS_TRACK   => '<b>About this track</b>',
+ ABOUT_THIS_TRACK   => '<b>About track <i>%s</i></b>',
 
  SUBTRACKS_SHOWN    => 'This track contains selectable subtracks. Click to modify the selection or change subtrack order.',
 
